@@ -21,7 +21,7 @@ except ImportError:
         "Could not import bayesian submodule due to missing pymc3 dependency.",
         ImportWarning)
 
-warnings.filterwarnings('ignore')
+warnings.filterwarnings("ignore", message="Module \"zipline.assets\" not found; mutltipliers will not be applied to position notionals.")
 
 #__version__ = get_versions()['version']
 #del get_versions
